diff --git a/scripts/test-add-device.sh b/scripts/test-add-device.sh
index 82ba2d42e0ee387297134ff9857295f518d0e2d3..bc02f14fd9b1cafabb094171134253a954669b9a 100755
--- a/scripts/test-add-device.sh
+++ b/scripts/test-add-device.sh
@@ -3,5 +3,7 @@ if [ $# -eq 0 ]
     echo 'you need to provide the password for the admin user'
     exit 1
 fi
+./artifacts/gosdnc login --controller 127.0.0.1:55055 --u admin --p $1
+./artifacts/gosdnc pnd use 5f20f34b-cbd0-4511-9ddc-c50cf6a3b49d
 ./artifacts/gosdnc device create -a 172.100.0.11:6030 -u admin -p admin --name="test-ceos-1"
 ./artifacts/gosdnc device list
diff --git a/scripts/test-list-devices.sh b/scripts/test-list-devices.sh
index ec6fa1320aab68d2456239ffece99a39cdf7e609..39a1c08b28bc8489b4010885fb6e3ed6eeec6c6b 100755
--- a/scripts/test-list-devices.sh
+++ b/scripts/test-list-devices.sh
@@ -5,4 +5,5 @@ if [ $# -eq 0 ]
 fi
 
 ./artifacts/gosdnc login --controller 127.0.0.1:55055 --u admin --p $1
+./artifacts/gosdnc pnd use 5f20f34b-cbd0-4511-9ddc-c50cf6a3b49d
 ./artifacts/gosdnc device list
diff --git a/scripts/test-list-pnd.sh b/scripts/test-list-pnd.sh
index 700ccb9e81f4c736b8ca95b6bcfb460410d21925..0287e0b499276eac7bbfde8e6984ef6f289a31d0 100755
--- a/scripts/test-list-pnd.sh
+++ b/scripts/test-list-pnd.sh
@@ -5,4 +5,5 @@ if [ $# -eq 0 ]
 fi
 
 ./artifacts/gosdnc login --controller 127.0.0.1:55055 --u admin --p $1
+./artifacts/gosdnc pnd use 5f20f34b-cbd0-4511-9ddc-c50cf6a3b49d
 ./artifacts/gosdnc list
diff --git a/controller/northbound/server/pnd.go b/controller/northbound/server/pnd.go
index 1bfa676fe14647ff04d02cd96f1e098c10a4567b..b587905a2930ca3b1528234c14601c703bd8a416 100644
--- a/controller/northbound/server/pnd.go
+++ b/controller/northbound/server/pnd.go
@@ -2,7 +2,6 @@ package server
 
 import (
 	"context"
-	"fmt"
 	"strings"
 	"time"
 
@@ -76,8 +75,8 @@ func (p PndServer) GetOnd(ctx context.Context, request *ppb.GetOndRequest) (*ppb
 	}, nil
 }
 
-// GetOndList returns a list of existing onds
-func (p PndServer) GetOndList(ctx context.Context, request *ppb.GetFlattenedOndListRequest) (*ppb.GetFlattenedOndListResponse, error) {
+// GetFlattenedOndList returns a list of existing onds
+func (p PndServer) GetFlattenedOndList(ctx context.Context, request *ppb.GetFlattenedOndListRequest) (*ppb.GetFlattenedOndListResponse, error) {
 	labels := prometheus.Labels{"service": "pnd", "rpc": "get"}
 	start := metrics.StartHook(labels, grpcRequestsTotal)
 	defer metrics.FinishHook(labels, start, grpcRequestDurationSecondsTotal, grpcRequestDurationSeconds)
@@ -254,8 +253,6 @@ func fillSbis(pnd networkdomain.NetworkDomain) ([]*spb.SouthboundInterface, erro
 		return nil, err
 	}
 
-	fmt.Printf("SBIS: %+v\n", sbis)
-
 	sbisToReturn := []*spb.SouthboundInterface{}
 
 	for _, sbi := range sbis {
@@ -264,8 +261,6 @@ func fillSbis(pnd networkdomain.NetworkDomain) ([]*spb.SouthboundInterface, erro
 		})
 	}
 
-	fmt.Printf("SBIS: %+v\n", sbisToReturn)
-
 	return sbisToReturn, nil
 }
 